@@ -15,14 +15,14 @@ import os
 import time
 from configparser import ConfigParser
 from datetime import datetime, timezone
+from io import StringIO
 from logging.config import fileConfig
 from subprocess import CalledProcessError
-from tempfile import mkstemp
 
 from botocore.config import Config
 from common.schedulers.slurm_commands import get_nodes_info
 from common.time_utils import seconds
-from common.utils import run_command, sleep_remaining_loop_time
+from common.utils import check_command_output, run_command, sleep_remaining_loop_time
 from retrying import retry
 from slurm_plugin.common import (
     DEFAULT_COMMAND_TIMEOUT,
@@ -55,7 +55,6 @@ class ComputemgtdConfig:
     }
 
     def __init__(self, config_file_path):
-        _, self._local_config_file = mkstemp()
         self._get_config(config_file_path)
 
     def __repr__(self):
@@ -69,12 +68,12 @@ class ComputemgtdConfig:
         config = ConfigParser()
         try:
             # Use subprocess based method to copy shared file to local to prevent hanging when NFS is down
-            run_command(
-                f"cat {config_file_path} > {self._local_config_file}",
+            config_str = check_command_output(
+                f"cat {config_file_path}",
                 timeout=DEFAULT_COMMAND_TIMEOUT,
                 shell=True,  # nosec
             )
-            config.read_file(open(self._local_config_file, "r"))
+            config.read_file(StringIO(config_str))
         except Exception:
             log.error(f"Cannot read computemgtd configuration file: {config_file_path}")
             raise
@@ -161,9 +160,9 @@ def _is_self_node_down(self_nodename):
     return True
 
 
-def _load_daemon_config():
+def _load_daemon_config(config_file):
     # Get program config
-    computemgtd_config = ComputemgtdConfig(os.path.join(COMPUTEMGTD_CONFIG_PATH))
+    computemgtd_config = ComputemgtdConfig(config_file)
     # Configure root logger
     try:
         fileConfig(computemgtd_config.logging_config, disable_existing_loggers=False)
@@ -176,12 +175,12 @@ def _load_daemon_config():
     return computemgtd_config
 
 
-def _run_computemgtd():
+def _run_computemgtd(config_file):
     """Run computemgtd actions."""
     # Initial default heartbeat time as computemgtd startup time
     last_heartbeat = datetime.now(tz=timezone.utc)
     log.info("Initializing clustermgtd heartbeat to be computemgtd startup time: %s", last_heartbeat)
-    computemgtd_config = _load_daemon_config()
+    computemgtd_config = _load_daemon_config(config_file)
     reload_config_counter = RELOAD_CONFIG_ITERATIONS
     while True:
         # Get current time
@@ -189,7 +188,7 @@ def _run_computemgtd():
 
         if reload_config_counter <= 0:
             try:
-                computemgtd_config = _load_daemon_config()
+                computemgtd_config = _load_daemon_config(config_file)
                 reload_config_counter = RELOAD_CONFIG_ITERATIONS
             except Exception as e:
                 log.warning("Unable to reload daemon config, using previous one.\nException: %s", e)
@@ -217,10 +216,13 @@ def _run_computemgtd():
 
 @retry(wait_fixed=seconds(LOOP_TIME))
 def main():
-    logging.basicConfig(level=logging.INFO, format="%(asctime)s %(levelname)s [%(module)s:%(funcName)s] %(message)s")
+    logging.basicConfig(
+        level=logging.INFO, format="%(asctime)s - [%(name)s:%(funcName)s] - %(levelname)s - %(message)s"
+    )
     log.info("Computemgtd Startup")
     try:
-        _run_computemgtd()
+        clustermgtd_config_file = os.environ.get("CONFIG_FILE", COMPUTEMGTD_CONFIG_PATH)
+        _run_computemgtd(clustermgtd_config_file)
     except Exception as e:
         log.exception("An unexpected error occurred: %s", e)
         raise
